@@ -1,8 +1,9 @@
 ## convert DVH to cumulative/differential DVH
+## with linearly interpolating the cumulative DVH
 convertDVH <-
 function(x, toType=c("asis", "cumulative", "differential"),
          toDoseUnit=c("asis", "GY", "CGY"),
-         interp=c("asis", "linear", "spline", "ksmooth", "smoothSpl"),
+         interp=c("asis", "linear"),
          nodes=NULL, rangeD=NULL, perDose=TRUE) {
     UseMethod("convertDVH")
 }
@@ -11,47 +12,54 @@ function(x, toType=c("asis", "cumulative", "differential"),
 convertDVH.matrix <-
 function(x, toType=c("asis", "cumulative", "differential"),
          toDoseUnit=c("asis", "GY", "CGY"),
-         interp=c("asis", "linear", "spline", "ksmooth", "smoothSpl"),
+         interp=c("asis", "linear"),
          nodes=NULL, rangeD=NULL, perDose=TRUE) {
     toType     <- match.arg(toType)
     toDoseUnit <- match.arg(toDoseUnit)
     interp     <- match.arg(interp)
     
-    if(!is.null(nodes)) { stopifnot(nodes > 2) }
+    if(!is.null(nodes)) { stopifnot(nodes > 2L) }
 
     ## matrix may include duplicate rows
     x <- unique(x)
 
-    ## when dose entries are duplicated with different volumes (cumulative DVH),
-    ## pick row with max volume
-    ## split matrix into rows with unique dose
-    ## preserve matrix class and keep col names with split.data.frame()
-    xL <- if(!all(is.na(x[ , "dose"]))) {
-        split.data.frame(x, x[ , "dose"])
+    dose <- if(!all(is.na(x[ , "dose"]))) {
+        x[ , "dose"]
     } else {
-        split.data.frame(x, x[ , "doseRel"])
-    }
-    
-    ## function to keep row with max volume
-    keepMaxVol <- function(xSub) {
-        idx <- if(!all(is.na(xSub[ , "volume"]))) {
-            xSub[ , "volume"] == max(xSub[ , "volume"])
-        } else{
-            xSub[ , "volumeRel"] == max(xSub[ , "volumeRel"])
-        }
-        
-        xSub[idx, ]
+        x[ , "doseRel"]
     }
 
-    ## apply keepMaxVol and re-bind to matrix
-    x <- do.call("rbind", lapply(xL, keepMaxVol))
-    rownames(x) <- NULL
+    ## when dose entries are duplicated with different volumes (cumulative DVH),
+    ## pick row with max volume
+    x <- if(any(duplicated(dose))) {
+        ## split matrix into rows with unique dose
+        ## preserve matrix class and keep col names with split.data.frame()
+        xL <- split.data.frame(x, dose)
+        
+        ## function to keep row with max volume
+        keepMaxVol <- function(xSub) {
+            idx <- if(!all(is.na(xSub[ , "volume"]))) {
+                xSub[ , "volume"] == max(xSub[ , "volume"])
+            } else{
+                xSub[ , "volumeRel"] == max(xSub[ , "volumeRel"])
+            }
+            
+            xSub[idx, ]
+        }
+    
+        ## apply keepMaxVol and re-bind to matrix
+        x <- do.call("rbind", lapply(xL, keepMaxVol))
+        rownames(x) <- NULL
+        x
+    } else {
+        x
+    }
 
     ## determine number of nodes for interpolation
     nodes <- if(!is.null(nodes)) {
-        if(nodes < 2) {
+        if(nodes < 2L) {
             warning("nodes is < 2 which is too few, - set to 2")
-            2
+            2L
         } else {
             nodes
         }
@@ -77,8 +85,8 @@ function(x, toType=c("asis", "cumulative", "differential"),
     ## convert DVH type
     if(toType == "asis") {
         ## nothing to convert
-        ## interpolate?
-        if(interp != "asis") {
+        ## linear interpolation?
+        if(interp == "linear") {
             ## if differential && perDose == FALSE
             ## normalize -> interpolate -> re-normalize 
             ## check if volume is already sorted -> cumulative DVH
@@ -88,12 +96,10 @@ function(x, toType=c("asis", "cumulative", "differential"),
                 volume
             }
     
-            if(isTRUE(all.equal(volumeSel, sort(volumeSel, decreasing=TRUE)))) {
-                DVHtype   <- "cumulative"
-                splMethod <- "monoH.FC"   # for spline interpolation -> monotonic
+            DVHtype <- if(isTRUE(all.equal(volumeSel, sort(volumeSel, decreasing=TRUE)))) {
+                "cumulative"
             } else {
-                DVHtype   <- "differential"
-                splMethod <- "fmm"        # for spline interpolation
+                "differential"
             }
             
             if((DVHtype == "differential") && !perDose) {
@@ -103,14 +109,9 @@ function(x, toType=c("asis", "cumulative", "differential"),
                 volumeRelNew <- -diff(volumeRel) / binW
             }
             
-            smFun <- switch(interp,
-                            linear=getInterpLin,
-                            ksmooth=getKSmooth,
-                            smoothSpl=getSmoothSpl,
-                            getInterpSpl) # default
-
-            sm <- smFun(doseConv, doseRel, volume, volumeRel, nodes=nodes,
-                        rangeD=rangeD, method=splMethod)
+            ## linear interpolation
+            sm <- getInterpLin(doseConv, doseRel, volume, volumeRel,
+                               nodes=nodes, rangeD=rangeD)
             doseNew    <- sm[ , "dose"]
             doseRelNew <- sm[ , "doseRel"]
 
@@ -133,38 +134,6 @@ function(x, toType=c("asis", "cumulative", "differential"),
         }
     } else if(toType == "cumulative") {
         ## convert from differential to cumulative DVH
-        ## interpolate?
-        if(interp != "asis") {
-            if(!perDose) {
-                ## if perDose == FALSE: normalize -> interpolate -> re-normalize
-                binW         <- diff(c(-doseConv[1], doseConv))
-                volumeNew    <- -diff(volume)    / binW
-                volumeRelNew <- -diff(volumeRel) / binW
-            }
-
-            smFun <- switch(interp,
-                            linear=getInterpLin,
-                            ksmooth=getKSmooth,
-                            smoothSpl=getSmoothSpl,
-                            getInterpSpl) # default
-
-            sm <- smFun(doseConv, doseRel, volume, volumeRel, nodes=nodes,
-                        rangeD=rangeD, method="monoH.FC")
-            doseConv <- sm[ , "dose"]
-            doseRel  <- sm[ , "doseRel"]
-            
-            if(!perDose) {
-                ## re-normalize to non-per-dose volume
-                ## start bin at 0 because no out-of-range interpolation
-                binW      <- diff(c(0, doseConv))
-                volume    <- sm[ , "volume"]    * binW
-                volumeRel <- sm[ , "volumeRel"] * binW
-            } else {
-                volume    <- sm[ , "volume"]
-                volumeRel <- sm[ , "volumeRel"]
-            }
-        }
-
         ## dose category half-widths
         doseCatHW    <- diff(doseConv)/2
         doseRelCatHW <- diff(doseRel)/2
@@ -191,12 +160,33 @@ function(x, toType=c("asis", "cumulative", "differential"),
         ## volume "survival" curve starting at max volume
         volumeNew    <- sum(volumeBin)    - c(0, cumsum(volumeBin))
         volumeRelNew <- sum(volumeRelBin) - c(0, cumsum(volumeRelBin))
+
+        ## linear interpolation?
+        if(interp == "linear") {
+            ## linear interpolation
+            sm <- getInterpLin(doseNew, doseRelNew, volumeNew, volumeRelNew,
+                               nodes=nodes, rangeD=rangeD)
+            doseNew      <- sm[ , "dose"]
+            doseRelNew   <- sm[ , "doseRel"]
+            volumeNew    <- sm[ , "volume"]
+            volumeRelNew <- sm[ , "volumeRel"]
+        }
     } else if(toType == "differential") {
         ## convert from cumulative to differential DVH
+        ## linear interpolation?
+        if(interp != "asis") {
+            ## linear interpolation
+            sm <- getInterpLin(doseConv, doseRel, volume, volumeRel,
+                               nodes=nodes, rangeD=rangeD)
+            doseConv  <- sm[ , "dose"]
+            doseRel   <- sm[ , "doseRel"]
+            volume    <- sm[ , "volume"]
+            volumeRel <- sm[ , "volumeRel"]
+        }
+
         ## dose category half-widths
         doseCatHW    <- diff(doseConv)/2
         doseRelCatHW <- diff(doseRel)/2
-
         doseNew      <- doseConv[-length(doseConv)] + doseCatHW
         doseRelNew   <-  doseRel[-length(doseRel)]  + doseRelCatHW
 
@@ -213,38 +203,6 @@ function(x, toType=c("asis", "cumulative", "differential"),
         } else {
             -diff(volumeRel)
         }
-
-        ## interpolate?
-        if(interp != "asis") {
-            ## if perDose == FALSE: normalize -> interpolate -> re-normalize
-            if(!perDose) {
-                volumeNew    <- -diff(volume)    / binW
-                volumeRelNew <- -diff(volumeRel) / binW
-            }
-
-            ## interpolate
-            smFun <- switch(interp,
-                            linear=getInterpLin,
-                            ksmooth=getKSmooth,
-                            smoothSpl=getSmoothSpl,
-                            getInterpSpl) # default
-
-            sm <- smFun(doseNew, doseRelNew, volumeNew, volumeRelNew,
-                        nodes=nodes, rangeD=rangeD, method="fmm")
-            doseNew    <- sm[ , "dose"]
-            doseRelNew <- sm[ , "doseRel"]
-
-            if(!perDose) {
-                ## re-normalize to non-per-dose volume
-                ## start bin at 0 because no out-of-range interpolation
-                binW         <- diff(c(0, doseNew))
-                volumeNew    <- sm[ , "volume"]   *binW
-                volumeRelNew <- sm[ , "volumeRel"]*binW
-            } else {
-                volumeNew    <- sm[ , "volume"]
-                volumeRelNew <- sm[ , "volumeRel"]
-            }
-        }
     }
 
     cbind(dose=doseNew, doseRel=doseRelNew,
@@ -255,7 +213,7 @@ function(x, toType=c("asis", "cumulative", "differential"),
 convertDVH.DVHs <-
 function(x, toType=c("asis", "cumulative", "differential"),
          toDoseUnit=c("asis", "GY", "CGY"),
-         interp=c("asis", "linear", "spline", "ksmooth", "smoothSpl"),
+         interp=c("asis", "linear"),
          nodes=NULL, rangeD=NULL, perDose=TRUE) {
     toType     <- match.arg(toType)
     toDoseUnit <- match.arg(toDoseUnit)
@@ -389,13 +347,13 @@ function(x, toType=c("asis", "cumulative", "differential"),
 convertDVH.DVHLst <-
 function(x, toType=c("asis", "cumulative", "differential"),
          toDoseUnit=c("asis", "GY", "CGY"),
-         interp=c("asis", "linear", "spline", "ksmooth", "smoothSpl"),
+         interp=c("asis", "linear"),
          nodes=NULL, rangeD=NULL, perDose=TRUE) {
     toType     <- match.arg(toType)
     toDoseUnit <- match.arg(toDoseUnit)
     interp     <- match.arg(interp)
 
-    if(!is.null(nodes)) { stopifnot(nodes > 2) }
+    if(!is.null(nodes)) { stopifnot(nodes > 2L) }
 
     dvhL <- Map(convertDVH, x, toType=toType, toDoseUnit=toDoseUnit,
                 interp=interp, nodes=list(nodes), rangeD=list(rangeD),
@@ -411,13 +369,13 @@ function(x, toType=c("asis", "cumulative", "differential"),
 convertDVH.DVHLstLst <-
 function(x, toType=c("asis", "cumulative", "differential"),
          toDoseUnit=c("asis", "GY", "CGY"),
-         interp=c("asis", "linear", "spline", "ksmooth", "smoothSpl"),
+         interp=c("asis", "linear"),
          nodes=NULL, rangeD=NULL, perDose=TRUE) {
     toType     <- match.arg(toType)
     toDoseUnit <- match.arg(toDoseUnit)
     interp     <- match.arg(interp)
     
-    if(!is.null(nodes)) { stopifnot(nodes > 2) }
+    if(!is.null(nodes)) { stopifnot(nodes > 2L) }
 
     dvhLL <- Map(convertDVH, x, toType=toType, toDoseUnit=toDoseUnit,
                  interp=interp, nodes=list(nodes), rangeD=list(rangeD),
